
enum { _xtlfreq = 20000000 , _clkfreq = 250'000'000  };


#include <propeller2.h>
#include <stdio.h>
#include <stdint.h>

struct __using("psram.spin2") psram;
struct __using("atsc_mod2.spin2") modulator;

#ifndef _clockfreq
#ifdef __P2__
#define _clockfreq() (*(unsigned int *)0x14)
#else
#define _clockfreq() _CLKFREQ
#endif
#endif

unsigned long time_us()
{
    unsigned long mhz = _clockfreq() / 1000000;
    return _cnt() / mhz;
}

#define PIN 0 // pin for RF output 


int main()
{
	unsigned long startTime, endTime;
	int  i, r;
	int  filesize=0;
	int  ram_amt=32*1024*1024;
	char  ram_file[4096];
	
	for( i=0;i<=4096;i++)
	{
		ram_file[i]=0x77;
	}
	printf("startup\n");
	psram.start();
	modulator.start(PIN,ram_file);
	//while(1); // TEST
	snprintf(ram_file,256,"/sd/STREAM.BIN");

	// initialize the file systems
#ifdef P9
	r = mount("/sd", _vfs_open_host());
	if (r == 0) {
		printf("mounted P9 as /\n");
	}
	//do_dir("/sd");
#else
	r = mount("/sd", _vfs_open_sdcard());
	if (r == 0) {
		printf("mounted SD card as /\n");
	}
	//do_dir("/sd");
#endif	
	printf("trying to open\n");
	FILE * f = fopen( ram_file, "rb" );
	if( !f )//|| ferror( f ) )
	{
		printf( "Error1: %x not found\n", ram_file );
		printf( "Error1: %s not found\n", ram_file );
		return -5;
	}
	fseek( f, 0, SEEK_END );
	long flen = ftell( f );
	fseek( f, 0, SEEK_SET );
	if( flen > ram_amt )
	{
		printf( "Error: Could not fit RAM image (%ld bytes) into %d\n", flen, ram_amt );
		return -6;
	}
	i=0;
	startTime = time_us();
	int c;
	for(;;) {
		c = fread( ram_file, 1, 512 , f );
		psram.write(ram_file,i,c);
		if ((i&0x1ffff)==0)
			printf("%d\n",i);
		i+=c;
		if (c < 511) break;
                   //psram_write_byte(i,c);
		   //break;
	}
	endTime = time_us();
	filesize=i;
	printf("done memcpy\n");
	printf("read %d bytes \n",filesize);
	// the below are incorrect because of counter overflow
	//printf ("in %u us\n", endTime - startTime);
	//printf ("%u us\n", (filesize*1000)/(endTime - startTime));

	printf("clock frequency = %u\n", _clockfreq());
	psram.read1(ram_file,0,512);
	printf("spot check: %x\n", *ram_file );

	i=0;
	while(1)
	{
		// ommitting the semicolon is great underhanded c	
		while( modulator.active_line()==0);
                psram.read1(ram_file,i,832);
		i+=832;
		if( i>=(filesize-1) ) 
		{
			i=0;
			printf("1");
		}

		while( modulator.active_line()==1);
                psram.read1(ram_file+(832*1),i,832);
		i+=832;
		if( i>=(filesize-1) ) 
		{
			i=0;
			printf("2");
		}

		while( modulator.active_line()==2);
                psram.read1(ram_file+(832*2),i,832);
		i+=832;
		if( i>=(filesize-1) ) 
		{
			i=0;
			printf("3");
		}

		while( modulator.active_line()==3);
                psram.read1(ram_file+(832*3),i,832);
		i+=832;
		if( i>=(filesize-1) ) 
		{
			i=0;
			printf("4");
		}

		//printf("%d\n",modulator.active_line());
	}
}
